#
# spec file for package gwenview5
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang

Name:           gwenview5
Version:        17.12.3
Release:        lp150.1.3
%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %global _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
Summary:        Image Viewer for KDE
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
Url:            http://www.kde.org
Source:         gwenview-%{version}.tar.xz
BuildRequires:  baloo5-devel
BuildRequires:  extra-cmake-modules >= %{kf5_version}
BuildRequires:  kactivities5-devel
BuildRequires:  kconfig-devel
BuildRequires:  kdelibs4support-devel
BuildRequires:  kf5-filesystem
BuildRequires:  kio-devel >= 5.4.0
BuildRequires:  libexiv2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libkdcraw-devel
BuildRequires:  libkipi-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  phonon4qt5-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5DBus) >= 5.2.0
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Script) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Svg) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.2.0
Provides:       gwenview = %{version}
Obsoletes:      gwenview < %{version}
%if %{with lang}
Recommends:     %{name}-lang
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gwenview is an image viewer for KDE. It features a folder tree
window and a file list window, providing navigation of file
hierarchies.

%if %{with lang}
%lang_package
%endif

%prep
%setup -q -n gwenview-%{version}

%build
  %cmake_kf5 -d build -- -DGWENVIEW_SEMANTICINFO_BACKEND="Baloo"
  %make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %kf5_find_htmldocs
  %endif

  %suse_update_desktop_file -r org.kde.gwenview       Graphics RasterGraphics Viewer KDE

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING*
%dir %{_datadir}/solid
%dir %{_datadir}/solid/actions
%dir %{_kf5_htmldir}
%dir %{_kf5_htmldir}/en
%doc %lang(en) %{_kf5_htmldir}/en/*/
%{_kf5_applicationsdir}/org.kde.gwenview.desktop
%{_kf5_appstreamdir}/
%{_kf5_bindir}/gwenview
%{_kf5_bindir}/gwenview_importer
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_libdir}/libgwenviewlib.so.*
%{_kf5_plugindir}/
%{_kf5_servicesdir}/
%{_kf5_sharedir}/gwenview/
%{_kf5_sharedir}/kxmlgui5/
%{_kf5_sharedir}/solid/actions/gwenview_*.desktop

%if %{with lang}
%files lang -f %{name}.lang
%doc COPYING*
%endif

%changelog
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Enlarge small SVGs too (kde#364822)
  * Fix URL Navigator margins
  * Hide fullscreen thumbnailbar when on-canvas image tools are in use
  * Remove symbolic icons in favor of standard icons
  * Fix thumbnail bar in View resetting to OFF when quitting in fullscreen
  * Fix background color for image view toolbar (crop/red-eye)
  * Update filename in fullscreen view on rename (kde#390332)
  * Add icons for context and sidebar menu
  * Improve thumbnail tooltip animation (kde#245091)
  * Save config when opening the config dialog (kde#390331)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Resize top bar in fullscreen view mode on toggling sidebar (kde#387784)
  * Disable auto saving window size in fullscreen mode
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix failing PlaceTreeModelTest autotest (kde#387824)
  * Respect custom filename for Copy/Move/Link To operations (kde#388144)
  * Fix displaying RW2 files with shared-mime-info 1.9
  * Fix expanding of baloo URLs in folders sidebar tree view
  * Revert changes caused by mistake from previous commit
  * Fixed places side panel for baloo urls
  * Update titlebar after image modification (kde#345980)
  * Correct margin for left sidebar (kde#381535)
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Update selection after renaming a file (kde#249001)
  * appdata: update doc URL, more https
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * General HiDPI enablement for Gwenview's importer
  * Initial focus to thumbnails in browse mode (kde#312631)
  * Indicate that Gwenview can open Targa images
  * Persist path for "Copy/Move/Link To" to config file
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Remove stray todo from gvpart.desktop
  * Try to keep ContextManager in sync with viewed files in MainWindow (kde#355493, kde#275807, kde#326190, kde#306835)
  * Make CFitsio optional
  * Update move/copy/link dialog window's title to reflect selected files
  * Fix zoom slider toolbuttons not disabling properly
  * Scroll wheel and touchpad zoom in smaller increments (kde#307637)
  * Add option to show file in File Manager
  * Apply full screen color scheme also to window decoration
  * Remove references to Android and KStars from CMake
  * Fix build with cfitsio
  * Add FITS format support
  * Add ccache support
  * Always show image rotation buttons in Image Operations sidebar when other operations are available (kde#354149)
  * Give Gwenview's Save As dialog a proper title: "Save Image" (kde#348221)
  * Fix CMake CMP0048 warning about project() without VERSION
  * Add .arcconfig
  * Replaced calls to the deprecated function KJobUiDelegate *ui().
  * Look at to use gwenview without install it
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Fix padding of "Fit Width" button (kde#385035)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix icon colors of inline context buttons also in full screen mode
  * Use standard QToolButtons so that their icons use the right colors (kde#383059)
  * Gwenview: suppressed unused interface variables compiler warnings.
  * Fix Gwenview Importer doesn't use date/time from EXIF
  * Reduce hyper-sensitive touchpad scroll-zoom speed (kde#378584)
  * Add 16:9 crop preset to Gwenview (kde#364007)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Remember paths for Copy-To and Move-To (kde#362474)
* Sat Aug 12 2017 jengelh@inai.de
- Make description neutral.
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Fix assert with Qt debug builds (kde#382542)
  * thumbnailprovider: downgrade missing size info debug from warning, kio doesn't store size info so it spams a lot
  * Use Q_DECL_OVERRIDE
  * Add toolbar menu entries
  * Port more deprecated functions and fix warnings
  * Support Apple OS X' image/x-icns
  * Fix part loading under kpartloader
  * Set organization domain to kde.org.
  * Do not set application data twice. It ends up in desktop file name being org.kde.org.kde.gwenview.
  * Add Fit to width
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.07.90.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Fix Enter and Escape keys in tool dialogs (crop, red eye) (kde#313806)
  * Fixed persistence of "Show Status Bar" action status
  * Add keyboard shortcut for statusbar toggling option
  * Re-enable all tests
  * Fix crop region size (kde#340459)
  * Re-enable importertest
  * Avoid data loss when importing pictures (kde#379615)
- Drop upstreamed patches:
  * fix-importer.patch
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * History (recentfolders) not working / folder never created (kde#379177)
  * Correctly load the translations
* Thu May 11 2017 wbauer@tmo.at
- Add fix-importer.patch to make the importer work and not cause
  data loss if "Delete" is chosen after the import (kde#379615)
- Provides/Obsoletes gwenview instead of Conflicts
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Do not set application data twice. It ends up in desktop file name being org.kde.org.kde.gwenview.
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.03.80.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix wrong action name for setDefaultShortcut() (kde#355313)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Dropped patches:
  + fix-multiple-arguments.diff
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Thu Sep 29 2016 alarrosa@suse.com
- Added a require for kdelibs4support since that package provides
  qimageioplugins services for jpeg, png, gif and other image formats
  and gwenview5 can't be used without it (boo#1001276).
* Wed Sep 28 2016 alarrosa@suse.com
- Added QUrl::AssumeLocalFile to fix-multiple-arguments.diff to
  mimic the patch accepted upstream
* Wed Sep 28 2016 alarrosa@suse.com
- Add fix-multiple-arguments.diff to fix handling of multiple local
  file arguments in the command line (boo#1001276)
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 18 2015 hrvoje.senjan@gmail.com
- Let gwenview5 be installable
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Sat Aug 22 2015 cgiboudeaux@gmx.com
- Initial package for Gwenview.
